"""
Entry point for running the Simple Voice Chat application as a module
using `python -m simple_voice_chat`.
"""

import sys
from .simple_voice_chat import main

if __name__ == "__main__":
    sys.exit(main())
